#ifndef NT2_INCLUDE_CONSTANTS_ONEO_8_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_ONEO_8_HPP_INCLUDED

#include <nt2/constant/include/constants/oneo_8.hpp>

#endif
